pub trait SettingsConvertExt {
// Required methods
fn to_dht_config(&self) -> DhtConfig;
fn to_dht_config_v6(&self) -> DhtConfig;
fn to_nat_config(&self) -> NatConfig;
fn to_utp_config(&self, port: u16) -> UtpConfig;
fn to_utp_config_v6(&self, port: u16) -> UtpConfig;
fn to_sam_tunnel_config(&self) -> SamTunnelConfig;
}Expand description
Conversions from Settings to the per-subsystem runtime configs.
Required Methods
Sourcefn to_dht_config(&self) -> DhtConfig
fn to_dht_config(&self) -> DhtConfig
Build the IPv4 DHT config, merging saved nodes ahead of the defaults.
Sourcefn to_dht_config_v6(&self) -> DhtConfig
fn to_dht_config_v6(&self) -> DhtConfig
Build the IPv6 DHT config, merging saved nodes ahead of the defaults.
Sourcefn to_nat_config(&self) -> NatConfig
fn to_nat_config(&self) -> NatConfig
Build the NAT (UPnP / NAT-PMP) port-mapping config.
Sourcefn to_utp_config(&self, port: u16) -> UtpConfig
fn to_utp_config(&self, port: u16) -> UtpConfig
Build the IPv4 uTP socket config bound to port.
Sourcefn to_utp_config_v6(&self, port: u16) -> UtpConfig
fn to_utp_config_v6(&self, port: u16) -> UtpConfig
Build the IPv6 uTP socket config bound to port.
Sourcefn to_sam_tunnel_config(&self) -> SamTunnelConfig
fn to_sam_tunnel_config(&self) -> SamTunnelConfig
Build the I2P SAM tunnel config from the I2P-related settings.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".